<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit5bed13e708bb075c72a6472b8aab7141
{
    public static $files = array (
        'a2c78434f64e5f5ed402f42eee19c025' => __DIR__ . '/..' . '/ipl/stdlib/src/functions_include.php',
        '6076de347104821999fcfc82c8f19bc5' => __DIR__ . '/..' . '/ipl/i18n/src/functions_include.php',
    );

    public static $prefixLengthsPsr4 = array (
        'i' => 
        array (
            'ipl\\Web\\' => 8,
            'ipl\\Validator\\' => 14,
            'ipl\\Stdlib\\' => 11,
            'ipl\\Sql\\' => 8,
            'ipl\\Orm\\' => 8,
            'ipl\\I18n\\' => 9,
            'ipl\\Html\\' => 9,
        ),
        'P' => 
        array (
            'Psr\\Http\\Message\\' => 17,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'ipl\\Web\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/web/src',
        ),
        'ipl\\Validator\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/validator/src',
        ),
        'ipl\\Stdlib\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/stdlib/src',
        ),
        'ipl\\Sql\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/sql/src',
        ),
        'ipl\\Orm\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/orm/src',
        ),
        'ipl\\I18n\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/i18n/src',
        ),
        'ipl\\Html\\' => 
        array (
            0 => __DIR__ . '/..' . '/ipl/html/src',
        ),
        'Psr\\Http\\Message\\' => 
        array (
            0 => __DIR__ . '/..' . '/psr/http-message/src',
        ),
    );

    public static $prefixesPsr0 = array (
        'E' => 
        array (
            'Evenement' => 
            array (
                0 => __DIR__ . '/..' . '/evenement/evenement/src',
            ),
        ),
        'A' => 
        array (
            'AssetLoader' => 
            array (
                0 => __DIR__ . '/../..' . '/',
            ),
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit5bed13e708bb075c72a6472b8aab7141::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit5bed13e708bb075c72a6472b8aab7141::$prefixDirsPsr4;
            $loader->prefixesPsr0 = ComposerStaticInit5bed13e708bb075c72a6472b8aab7141::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit5bed13e708bb075c72a6472b8aab7141::$classMap;

        }, null, ClassLoader::class);
    }
}
