<?php return array(
    'root' => array(
        'name' => 'icinga/icinga-php-library',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => 'ec69390abda538d1bd80eda74aa211f39417cab9',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.1',
            'version' => '3.0.1.0',
            'reference' => '531bfb9d15f8aa57454f5f0285b18bec903b8fb7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fortawesome/font-awesome' => array(
            'pretty_version' => '6.2.1',
            'version' => '6.2.1.0',
            'reference' => '96cafbd73ec4339b8c73c36673ce1518db82cc5c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fortawesome/font-awesome',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/icinga-php-library' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => 'ec69390abda538d1bd80eda74aa211f39417cab9',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/html' => array(
            'pretty_version' => 'v0.6.0',
            'version' => '0.6.0.0',
            'reference' => '239b215ab81205f69d8df2663b0fecb138562547',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/html',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/i18n' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'reference' => '3ee2a8c0c38879cb743c866d9202f8620d4c2800',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/i18n',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/orm' => array(
            'pretty_version' => 'v0.4.1',
            'version' => '0.4.1.0',
            'reference' => '0b76de078b9ebff608ce07b1ea051fa7d82f6261',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/orm',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/sql' => array(
            'pretty_version' => 'v0.6.0',
            'version' => '0.6.0.0',
            'reference' => 'cb4f5a239bfb5046a4ad7206d77a1c1d82d6cdce',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/sql',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/stdlib' => array(
            'pretty_version' => 'v0.12.1',
            'version' => '0.12.1.0',
            'reference' => 'be75213aa3ba1c73756368f17be20a2bcbdeb835',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/stdlib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/validator' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'reference' => 'b8af9ef02654e04b63c6f28507a80270f5248ecb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/web' => array(
            'pretty_version' => 'v0.6.0',
            'version' => '0.6.0.0',
            'reference' => 'ded069e649f0c4dccca27b36bd6d6d3f34d5bfcb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/web',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
